@@ -2,7 +2,7 @@ package SQL::Abstract::More;
 use strict;
 use warnings;
 
-use SQL::Abstract 1.73;
+use SQL::Abstract 1.84;
 use parent 'SQL::Abstract';
 use MRO::Compat;
 use mro 'c3'; # implements next::method
@@ -12,18 +12,23 @@ use Params::Validate  qw/validate SCALAR SCALARREF CODEREF ARRAYREF HASHREF
 use Scalar::Util      qw/blessed reftype/;
 use Carp;
 
-our $VERSION = '1.28';
-
 # import the "puke" function from SQL::Abstract (kind of "die")
 BEGIN {*puke = \&SQL::Abstract::puke;}
 
+# remove all previously defined or imported functions
+use namespace::clean;
+
+our $VERSION = '1.33';
+
 
 #----------------------------------------------------------------------
 # utility function : cheap version of Scalar::Does (too heavy to be included)
 #----------------------------------------------------------------------
 my %meth_for = (
-  ARRAY => '@{}',
-  HASH  => '%{}',
+  ARRAY  => '@{}',
+  HASH   => '%{}',
+  SCALAR => '${}',
+  CODE   => '&{}',
  );
 
 sub does ($$) {
@@ -32,12 +37,9 @@ sub does ($$) {
   return defined $reft && $reft eq $type
       || blessed $data && overload::Method($data, $meth_for{$type});
 }
-
-
-#----------------------------------------------------------------------
-# remove all previously defined functions
-#----------------------------------------------------------------------
-use namespace::clean;
+# Note : this is a utility function, not a method; but it is declared
+# _after_ namespace::clean so that it can remain visible by external
+# modules. In particular, DBIx::DataModel imports this function.
 
 
 #----------------------------------------------------------------------
@@ -79,8 +81,9 @@ my %limit_offset_dialects = (
 my %common_join_syntax = (
   '<=>' => '%s INNER JOIN %s ON %s',
    '=>' => '%s LEFT OUTER JOIN %s ON %s',
-  '<='  => '%s RIGHT JOIN %s ON %s',
+  '<='  => '%s RIGHT OUTER JOIN %s ON %s',
   '=='  => '%s NATURAL JOIN %s',
+  '>=<' => '%s FULL OUTER JOIN %s ON %s',
 );
 my %right_assoc_join_syntax = %common_join_syntax;
 s/JOIN %s/JOIN (%s)/ foreach values %right_assoc_join_syntax;
@@ -143,11 +146,12 @@ my %params_for_insert = (
   -returning    => {type => SCALAR|ARRAYREF|HASHREF, optional => 1},
 );
 my %params_for_update = (
-  -table        => {type => SCALAR},
+  -table        => {type => SCALAR|SCALARREF|ARRAYREF},
   -set          => {type => HASHREF},
   -where        => {type => SCALAR|ARRAYREF|HASHREF, optional => 1},
   -order_by     => {type => SCALAR|ARRAYREF|HASHREF, optional => 1},
   -limit        => {type => SCALAR,                  optional => 1},
+  -returning    => {type => SCALAR|ARRAYREF|HASHREF, optional => 1},
 );
 my %params_for_delete = (
   -from         => {type => SCALAR},
@@ -186,12 +190,10 @@ sub new {
   # check some of the params for parent -- because SQLA doesn't do it :-(
   !$params{quote_char} || exists $params{name_sep}
     or carp "when 'quote_char' is present, 'name_sep' should be present too";
-  # TODO : validate(%params)
 
   # call parent constructor
   my $self = $class->next::method(%params);
 
-
   # inject into $self
   $self->{$_} = $more_self->{$_} foreach keys %$more_self;
 
@@ -227,17 +229,14 @@ sub select {
   # if got positional args, this is not our job, just delegate to the parent
   return $self->next::method(@_) if !&_called_with_named_args;
 
-  # declare variables and parse arguments;
-  my ($join_info, %aliased_columns);
+  my %aliased_columns;
+
+  # parse arguments
   my %args = validate(@_, \%params_for_select);
 
   # compute join info if the datasource is a join
-  if (ref $args{-from} eq 'ARRAY' && $args{-from}[0] eq '-join') {
-    my @join_args = @{$args{-from}};
-    shift @join_args;           # drop initial '-join'
-    $join_info   = $self->join(@join_args);
-    $args{-from} = \($join_info->{sql});
-  }
+  my $join_info = $self->_compute_join_info($args{-from});
+  $args{-from}  = \($join_info->{sql}) if $join_info;
 
   # reorganize columns; initial members starting with "-" are extracted
   # into a separate list @post_select, later re-injected into the SQL
@@ -305,24 +304,9 @@ sub select {
   # add ORDER BY if needed
   if (my $order = $args{-order_by}) {
 
-    # force scalar into an arrayref
-    $order = [$order] if not ref $order;
-
-    # restructure array data
-    if (ref $order eq 'ARRAY') {
-      my @clone = @$order;      # because we will modify items 
-
-      # '-' and '+' prefixes are translated into {-desc/asc => } hashrefs
-      foreach my $item (@clone) {
-        next if !$item or ref $item;
-        $item =~ s/^-//  and $item = {-desc => $item} and next;
-        $item =~ s/^\+// and $item = {-asc  => $item};
-      }
-      $order = \@clone;
-    }
-
-    my $sql_order = $self->where(undef, $order);
+    my ($sql_order, @orderby_bind) = $self->_order_by($order);
     $sql .= $sql_order;
+    push @bind, @orderby_bind;
   }
 
   # add LIMIT/OFFSET if needed
@@ -364,19 +348,10 @@ sub insert {
     my %args = validate(@_, \%params_for_insert);
     @old_API_args = @args{qw/-into -values/};
 
-    # if present, "-returning" may be a scalar, arrayref or hashref; the latter
-    # is interpreted as .. RETURNING ... INTO ...
-    if (my $returning = $args{-returning}) {
-      if (does $returning, 'HASH') {
-        my @keys = sort keys %$returning
-          or croak "-returning => {} : the hash is empty";
-        push @old_API_args, {returning => \@keys};
-        $returning_into = [@{$returning}{@keys}];
-      }
-      else {
-        push @old_API_args, {returning => $returning};
-      }
-    }
+    # deal with -returning arg
+    ($returning_into, my $old_API_options) 
+      = $self->_compute_returning($args{-returning});
+    push @old_API_args, $old_API_options if $old_API_options;
   }
   else {
     @old_API_args = @_;
@@ -394,28 +369,73 @@ sub insert {
   return ($sql, @bind);
 }
 
+
 sub update {
   my $self = shift;
 
+  my $join_info;
   my @old_API_args;
+  my $returning_into;
   my %args;
   if (&_called_with_named_args) {
     %args = validate(@_, \%params_for_update);
+
+    # compute join info if the datasource is a join
+    $join_info = $self->_compute_join_info($args{-table});
+    $args{-table} = \($join_info->{sql}) if $join_info;
+
     @old_API_args = @args{qw/-table -set -where/};
+
+    # deal with -returning arg
+    ($returning_into, my $old_API_options) 
+      = $self->_compute_returning($args{-returning});
+    push @old_API_args, $old_API_options if $old_API_options;
   }
   else {
     @old_API_args = @_;
   }
 
-  # call clone of parent method
+  # call clone of parent method and merge with bind values from $join_info
   my ($sql, @bind) = $self->_overridden_update(@old_API_args);
+  unshift @bind, @{$join_info->{bind}} if $join_info;
 
   # maybe need to handle additional args
   $self->_handle_additional_args_for_update_delete(\%args, \$sql, \@bind);
 
+  # inject more stuff if using Oracle's "RETURNING ... INTO ..."
+  if ($returning_into) {
+    $sql .= ' INTO ' . join(", ", ("?") x @$returning_into);
+    push @bind, @$returning_into;
+  }
+
   return ($sql, @bind);
 }
 
+sub _compute_returning {
+  my ($self, $arg_returning) = @_; 
+
+  my ($returning_into, $old_API_options);
+
+  if ($arg_returning) {
+    # if present, "-returning" may be a scalar, arrayref or hashref; the latter
+    # is interpreted as .. RETURNING ... INTO ...
+
+
+    if (does $arg_returning, 'HASH') {
+      my @keys = sort keys %$arg_returning
+        or croak "-returning => {} : the hash is empty";
+
+      $old_API_options = {returning => \@keys};
+      $returning_into  = [@{$arg_returning}{@keys}];
+    }
+    else {
+      $old_API_options = {returning => $arg_returning};
+    }
+  }
+
+  return ($returning_into, $old_API_options);
+}
+
 
 sub _handle_additional_args_for_update_delete {
   my ($self, $args, $sql_ref, $bind_ref) = @_;
@@ -432,7 +452,27 @@ sub _handle_additional_args_for_update_delete {
   }
 }
 
+sub _order_by {
+  my ($self, $order) = @_;
 
+  # force scalar into an arrayref
+  $order = [$order] if not ref $order;
+
+  # restructure array data
+  if (does $order, 'ARRAY') {
+    my @clone = @$order;      # because we will modify items
+
+    # '-' and '+' prefixes are translated into {-desc/asc => } hashrefs
+    foreach my $item (@clone) {
+      next if !$item or ref $item;
+      $item =~ s/^-//  and $item = {-desc => $item} and next;
+      $item =~ s/^\+// and $item = {-asc  => $item};
+    }
+    $order = \@clone;
+  }
+
+  return $self->next::method($order);
+}
 
 sub delete {
   my $self = shift;
@@ -534,12 +574,11 @@ sub bind_params {
   $sth->isa('DBI::st') or croak "sth argument is not a DBI statement handle";
   foreach my $i (0 .. $#bind) {
     my $val = $bind[$i];
-    my $ref = ref $val || '';
-    if ($ref eq 'SCALAR') {
+    if (does $val, 'SCALAR') {
       # a scalarref is interpreted as an INOUT parameter
       $sth->bind_param_inout($i+1, $val, $INOUT_MAX_LEN);
     }
-    elsif ($ref eq 'ARRAY' and
+    elsif (does $val, 'ARRAY' and
              my ($bind_meth, @args) = $self->is_bind_value_with_type($val)) {
       # either 'bind_param' or 'bind_param_inout', with 2 or 3 args
       $sth->$bind_meth($i+1, @args);
@@ -587,6 +626,19 @@ sub is_bind_value_with_type {
 # private utility methods for 'join'
 #----------------------------------------------------------------------
 
+sub _compute_join_info {
+  my ($self, $table_arg) = @_;
+
+  if (does($table_arg, 'ARRAY') && $table_arg->[0] eq '-join') {
+    my @join_args = @$table_arg;
+    shift @join_args;                # drop initial '-join'
+    return $self->join(@join_args);
+  }
+  else {
+    return;
+  }
+}
+
 sub _parse_table {
   my ($self, $table) = @_;
 
@@ -634,27 +686,33 @@ sub _parse_join_spec {
 
   # accumulate conditions as pairs ($left => \"$op $right")
   my @conditions;
-  foreach my $cond (split /,/, $cond_list) {
+  my @using;
+  foreach my $cond (split /,\s*/, $cond_list) {
     # parse the condition (left and right operands + comparison operator)
-    my ($left, $cmp, $right) = split /([<>=!^]{1,2})/, $cond
-      or croak "can't parse join condition: $cond";
+    my ($left, $cmp, $right) = split /([<>=!^]{1,2})/, $cond;
+    if ($cmp && $right) {
+      # if operands are not qualified by table/alias name, add sprintf hooks
+      $left  = '%1$s.' . $left   unless $left  =~ /\./;
+      $right = '%2$s.' . $right  unless $right =~ /\./ or $right eq $placeholder;
 
-    # if operands are not qualified by table/alias name, add sprintf hooks
-    $left  = '%1$s.' . $left   unless $left  =~ /\./;
-    $right = '%2$s.' . $right  unless $right =~ /\./ or $right eq $placeholder;
-
-    # add this pair into the list; right operand is either a bind value
-    # or an identifier within the right table
-    $right = $right eq $placeholder ? shift @constants : {-ident => $right};
-    push @conditions, $left, {$cmp => $right};
+      # add this pair into the list; right operand is either a bind value
+      # or an identifier within the right table
+      $right = $right eq $placeholder ? shift @constants : {-ident => $right};
+      push @conditions, $left, {$cmp => $right};
+    }
+    elsif ($cond =~ /^\w+$/) {
+      push @using, $cond;
+    }
+    else {puke "can't parse join condition: $cond"}
   }
 
-  # list becomes an arrayref or hashref (for SQLA->where())
-  my $join_on = $bracket eq '[' ? [@conditions] : {@conditions};
+  # build join hashref
+  my $join_hash = {operator  => $op};
+  $join_hash->{using} = \@using                        if @using;
+  $join_hash->{condition}
+    = $bracket eq '[' ? [@conditions] : {@conditions}  if @conditions;
 
-  # return a new join spec
-  return {operator  => $op,
-          condition => $join_on};
+  return $join_hash;
 }
 
 sub _single_join {
@@ -664,18 +722,32 @@ sub _single_join {
   @_ = reverse @_ if $self->{join_assoc_right};
   my ($left, $join_spec, $right) = @_;
 
-  # compute the "ON" clause
-  my ($sql, @bind) = $self->where($join_spec->{condition});
-  $sql =~ s/^\s*WHERE\s+//;
-
   # syntax for assembling all elements
   my $syntax = $self->{join_syntax}{$join_spec->{operator}};
 
-  # $sql may _intentionally_ omit %.. parameters, so disable warnings
-  { no if $] ge '5.022000', warnings => 'redundant';
+  my ($sql, @bind);
 
-    # substitute left/right tables names for '%1$s', '%2$s'
-    $sql = sprintf $sql, $left->{name}, $right->{name};
+  { no if $] ge '5.022000', warnings => 'redundant';
+    # because sprintf instructions  may _intentionally_ omit %.. parameters
+
+    if ($join_spec->{using}) {
+      not $join_spec->{condition}
+        or croak "join specification has both {condition} and {using} fields";
+
+      $syntax =~ s/\bON\s+%s/USING (%s)/;
+      $sql = CORE::join ",", @{$join_spec->{using}};
+    }
+    elsif ($join_spec->{condition}) {
+      not $join_spec->{using}
+        or croak "join specification has both {condition} and {using} fields";
+
+      # compute the "ON" clause
+      ($sql, @bind) = $self->where($join_spec->{condition});
+      $sql =~ s/^\s*WHERE\s+//;
+
+      # substitute left/right tables names for '%1$s', '%2$s'
+      $sql = sprintf $sql, $left->{name}, $right->{name};
+    }
 
     # build the final sql
     $sql = sprintf $syntax, $left->{sql}, $right->{sql}, $sql;
@@ -696,6 +768,31 @@ sub _single_join {
 }
 
 
+
+# sub _try_replace_ON_by_USING {
+#   my ($self, $syntax, $sql) = @_;
+
+#   # if there is an ON clause, replace it by a USING clause
+#   $syntax =~ s/\bON\s+%s/USING (%s)/ or return;
+
+#   # if there are equality conditions like Table1.col=Table2.col, just keep col
+#   my $n_cond = $sql =~ s/\w+\.(\w+)\s*=\s*\w+\.\1\b/$1/g or return;
+
+#   # if there were several equalities, replace the AND's by commas
+#   my $n_and  = $sql =~ s/\s+\bAND\b/,/g;
+
+#   # the number of equalities must match the number of AND's minus 1
+#   $n_cond == $n_and + 1 or return;
+
+#   # remove unnecessary parentheses
+#   $sql =~ s/^(\(\s*)+// and $sql =~ s/(\)\s*)+$//;
+
+#   # all criteria are good, let's replace strings in the caller (call-by-name)
+#   @_[1, 2] = ($syntax, $sql);
+# }
+
+
+
 #----------------------------------------------------------------------
 # override of parent's "_where_field_IN"
 #----------------------------------------------------------------------
@@ -869,65 +966,63 @@ sub _assert_no_bindtype_columns {
            . 'with ...->new(bindtype => "columns")';
 }
 
-sub _insert_values {
+
+sub _insert_value { # called from _insert_values() in parent class
+
   # unfortunately, we can't just override the ARRAYREF part, so the whole
   # parent method is copied here
-  my ($self, $data) = @_;
+
+  my ($self, $column, $v) = @_;
 
   my (@values, @all_bind);
-  foreach my $column (sort keys %$data) {
-    my $v = $data->{$column};
+  $self->_SWITCH_refkind($v, {
 
-    $self->_SWITCH_refkind($v, {
-
-      ARRAYREF => sub {
-        if ($self->{array_datatypes}
-            || $self->is_bind_value_with_type($v)) { 
-          # if array datatype are activated or this is a [$val, \%type] struct
-          push @values, '?';
-          push @all_bind, $self->_bindtype($column, $v);
-        }
-        else {
-          # otherwise, literal SQL with bind
-          my ($sql, @bind) = @$v;
-          $self->_assert_bindval_matches_bindtype(@bind);
-          push @values, $sql;
-          push @all_bind, @bind;
-        }
-      },
-
-      ARRAYREFREF => sub { # literal SQL with bind
-        my ($sql, @bind) = @${$v};
+    ARRAYREF => sub {
+      if ($self->{array_datatypes} # if array datatype are activated
+            || $self->is_bind_value_with_type($v)) { # or if this is a bind val
+        push @values, '?';
+        push @all_bind, $self->_bindtype($column, $v);
+      }
+      else {                  # else literal SQL with bind
+        my ($sql, @bind) = @$v;
         $self->_assert_bindval_matches_bindtype(@bind);
         push @values, $sql;
         push @all_bind, @bind;
-      },
+      }
+    },
 
-      # THINK : anything useful to do with a HASHREF ?
-      HASHREF => sub {  # (nothing, but old SQLA passed it through)
-        #TODO in SQLA >= 2.0 it will die instead
-        SQL::Abstract::belch("HASH ref as bind value in insert is not supported");
-        push @values, '?';
-        push @all_bind, $self->_bindtype($column, $v);
-      },
+    ARRAYREFREF => sub {        # literal SQL with bind
+      my ($sql, @bind) = @${$v};
+      $self->_assert_bindval_matches_bindtype(@bind);
+      push @values, $sql;
+      push @all_bind, @bind;
+    },
 
-      SCALARREF => sub {  # literal SQL without bind
-        push @values, $$v;
-      },
+    # THINK : anything useful to do with a HASHREF ?
+    HASHREF => sub {       # (nothing, but old SQLA passed it through)
+      #TODO in SQLA >= 2.0 it will die instead
+      SQL::Abstract::belch "HASH ref as bind value in insert is not supported";
+      push @values, '?';
+      push @all_bind, $self->_bindtype($column, $v);
+    },
 
-      SCALAR_or_UNDEF => sub {
-        push @values, '?';
-        push @all_bind, $self->_bindtype($column, $v);
-      },
+    SCALARREF => sub {          # literal SQL without bind
+      push @values, $$v;
+    },
 
-     });
+    SCALAR_or_UNDEF => sub {
+      push @values, '?';
+      push @all_bind, $self->_bindtype($column, $v);
+    },
 
-  }
+  });
 
-  my $sql = $self->_sqlcase('values')." ( ".CORE::join(", ", @values)." )";
+  my $sql = CORE::join(", ", @values);
   return ($sql, @all_bind);
 }
 
+
+
 sub _overridden_update {
   # unfortunately, we can't just override the ARRAYREF part, so the whole
   # parent method is copied here
@@ -936,6 +1031,7 @@ sub _overridden_update {
   my $table = $self->_table(shift);
   my $data  = shift || return;
   my $where = shift;
+  my $options = shift;
 
   # first build the 'SET' part of the sql statement
   my (@set, @all_bind);
@@ -999,6 +1095,12 @@ sub _overridden_update {
     push @all_bind, @where_bind;
   }
 
+  if ($options->{returning}) {
+    my ($returning_sql, @returning_bind) = $self->_update_returning($options);
+    $sql .= $returning_sql;
+    push @all_bind, @returning_bind;
+  }
+
   return wantarray ? ($sql, @all_bind) : $sql;
 }
 
@@ -1049,7 +1151,7 @@ sub _choose_LIMIT_OFFSET_dialect {
   my $method = $limit_offset_dialects{$dialect}
     or croak "no such limit_offset dialect: $dialect";
   $self->{limit_offset} = $method;
-};
+}
 
 
 #----------------------------------------------------------------------
@@ -1230,6 +1332,7 @@ values are associated SQL clauses with placeholders
 in C<sprintf> format. The default is described
 below under the L</join> method.
 
+
 =item join_assoc_right
 
 A boolean telling if multiple joins should be associative 
@@ -1509,7 +1612,7 @@ specified either by a plain string or by an array of strings.
 adds a C<HAVING> clause in the SQL statement (only makes
 sense together with a C<GROUP BY> clause).
 This is like a C<-where> clause, except that the criteria
-are applied after grouping has occured.
+are applied after grouping has occurred.
 
 
 =item C<< -order_by => \@order >>
@@ -1649,11 +1752,12 @@ present module is there for help. Example:
 
   # named parameters, handled in this class
   ($sql, @bind) = $sqla->update(
-    -table    => $table,
-    -set      => {col => $val, ...},
-    -where    => \%conditions,
-    -order_by => \@order,
-    -limit    => $limit,
+    -table     => $table,
+    -set       => {col => $val, ...},
+    -where     => \%conditions,
+    -order_by  => \@order,
+    -limit     => $limit,
+    -returning => $return_structure,
   );
 
 This works in the same spirit as the L</insert> method above.
@@ -1664,6 +1768,8 @@ they improve the readability of the client's code.
 Few DBMS would support parameters C<-order_by> and C<-limit>, but
 MySQL does -- see L<http://dev.mysql.com/doc/refman/5.6/en/update.html>.
 
+Optional parameter C<-returning> works like for the L</insert> method.
+
 
 =head2 delete
 
@@ -1775,6 +1881,7 @@ SQL JOIN clauses :
    '=>' => '%s LEFT OUTER JOIN %s ON %s',
   '<='  => '%s RIGHT JOIN %s ON %s',
   '=='  => '%s NATURAL JOIN %s',
+  '>=<' => '%s FULL OUTER JOIN %s ON %s',
 
 This operator table can be overridden through
 the C<join_syntax> parameter of the L</new> method.
@@ -1840,9 +1947,49 @@ is parsed into
     'Table2',
   ]
 
-
 Hashrefs for join specifications as shown above can be passed directly
 as arguments, instead of the simple string representation.
+For example the L<DBIx::DataModel> ORM uses hashrefs for communicating
+with C<SQL::Abstract::More>.
+
+=head3 joins with USING clause instead of ON
+
+In most DBMS, when column names on both sides of a join are identical, the join
+can be expressed as
+
+  SELECT * FROM T1 INNER JOIN T2 USING (A, B)
+
+instead of
+
+  SELECT * FROM T1 INNER JOIN T2 ON T1.A=T2.A AND T1.B=T2.B
+
+The advantage of this syntax with a USING clause is that the joined
+columns will appear only once in the results, and they do not need to
+be prefixed by a table name if they are needed in the select list or
+in the WHERE part of the SQL.
+
+To express joins with the USING syntax in C<SQL::Abstract::More>, just
+mention the column names within curly braces, without any equality
+operator. For example
+
+  ->join(qw/Table1 {a,b} Table2 {c} Table3/)
+
+will generate
+
+  SELECT * FROM Table1 INNER JOIN Table2 USING (a,b)
+                       INNER JOIN Table3 USING (c)
+
+In this case the internal hashref representation has the following shape :
+
+  {
+    operator  => '<=>',
+    using     => [ 'a', 'b'],
+  }
+
+When they are generated directy by the client code, internal hashrefs
+must have I<either> a C<condition> field I<or> a C<using> field; it is
+an error to have both.
+
 
 =head3 Return value
 
@@ -1979,6 +2126,22 @@ L</bind_params> from the present module to perform the appropriate
 bindings before executing the statement.
 
 
+=head1 EXPORTED FUNCTIONS
+
+=head2 does()
+
+  use SQL::Abstract::More qw/does/;
+
+  if (does $ref, 'ARRAY') {...}
+
+This module contains a very cheap version of a C<does()> method, that
+checks whether a given reference can act as an ARRAY, HASH, SCALAR or
+CODE. This was designed for the limited internal needs of this module
+and of L<DBIx::DataModel>; for more complete implementations of a
+C<does()> method, see L<Scalar::Does>, L<UNIVERSAL::DOES> or
+L<Class::DOES>.
+
+
 =head1 AUTHOR
 
 Laurent Dami, C<< <laurent dot dami at cpan dot org> >>
@@ -1986,7 +2149,8 @@ Laurent Dami, C<< <laurent dot dami at cpan dot org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-sql-abstract-more at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SQL-Abstract-More>.  I will be notified, and then you'll
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SQL-Abstract-More>. 
+I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 
@@ -2022,7 +2186,7 @@ L<https://metacpan.org/module/SQL::Abstract::More>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2016 Laurent Dami.
+Copyright 2011-2017 Laurent Dami.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
